@@ -1711,12 +1711,14 @@ gnome_cups_printer_finalize (GObject *object)
 	printer->details->state_reasons = NULL;
 	
 	g_free (printer->details->printer_name);
+	g_free (printer->details->full_state);
 	g_free (printer->details->description);
 	g_free (printer->details->location);
 	g_free (printer->details->device_uri);
 	g_free (printer->details->state_message);
-	g_free (printer->details->full_state);
-
+	g_free (printer->details->info);
+	g_free (printer->details->make_and_model);
+	g_free (printer->details->printer_uri);
 	g_free (printer->details);
 }
 
