@@ -1,3 +1,4 @@
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* FIXME: gone printers that come back to life */
 
 #include <config.h>
@@ -43,7 +44,7 @@ static const char *job_state_strings[] =
 	N_("Paused"),
 	N_("Printing"),
 	N_("Stopped"),
-	N_("Cancelled"),
+	N_("Canceled"),
 	N_("Aborted"),
 	N_("Completed")
 };
@@ -298,14 +299,19 @@ get_jobs_on_server (GnomeCupsQueue *queue, const char *server)
 {
 	ipp_t *request;
 	const char *printer_name;
+	GnomeCupsPrinter *printer;
 
 	if (queue->details->get_jobs_request_id > 0)
 		return;
 
 	printer_name = queue->details->queue_name;
+	printer = gnome_cups_printer_get_existing (printer_name);
+	g_return_if_fail (printer != NULL);
 
 	request = gnome_cups_request_new_for_printer (IPP_GET_JOBS,
-						      printer_name);
+						      printer);
+	g_object_unref (printer);
+
 	queue->details->get_jobs_request_id =
 		gnome_cups_request_execute_async (request, server, "/",
 						  get_jobs_cb,
@@ -418,24 +424,19 @@ gnome_cups_queue_get_job (GnomeCupsQueue *queue,
 static void
 update_queue (GnomeCupsQueue *queue)
 {
-	GnomeCupsPrinter *printer;
 	gchar *printer_host = NULL;
-
-	printer = gnome_cups_printer_get_existing (queue->details->queue_name);
+	GnomeCupsPrinter *printer = gnome_cups_printer_get_existing (
+		queue->details->queue_name);
 	
-	if (printer) {
+	if (printer != NULL) {
 		printer_host = _gnome_cups_printer_get_host (printer);
 		g_object_unref (printer);
-	}
-
-	if (!printer_host)
+	} else
 		return;
 
-	if (gnome_cups_printer_get_is_local (printer))
-		get_jobs_on_server (queue, NULL);
-	else
-		get_jobs_on_server (queue, printer_host);
-
+	get_jobs_on_server (queue,
+		(gnome_cups_printer_get_is_local (printer) || printer_host == NULL)
+		? NULL : printer_host);
 	g_free (printer_host);
 }
 
@@ -559,24 +560,16 @@ gnome_cups_queue_get_existing (const char *queue_name)
 }
 
 static gboolean 
-check_exists (const char *queue)
+check_exists (const char *name)
 {
-	GError *error = NULL;
-	ipp_t *request;
-	ipp_t *response;
+	gboolean exists;
+	GnomeCupsPrinter *printer;
 
-	request = gnome_cups_request_new_for_printer (IPP_GET_PRINTER_ATTRIBUTES,
-						      queue);
-	response = gnome_cups_request_execute (request, NULL, "/", &error);
+	printer = gnome_cups_printer_get (name);
+	exists = printer != NULL;
+	g_object_unref (printer);
 
-	ippDelete (response);
-
-	if (error) {
-		g_error_free (error);
-		return FALSE;
-	} else {
-		return TRUE;
-	}
+	return exists;
 }
 
 GnomeCupsQueue *
